==> org-lsst-ccs-subsystem-fcs-main-5.0.4-sources.jar: org/lsst/ccs/subsystems/fcs/simulation/SimuCarouselClampController.java <==

package org.lsst.ccs.subsystems.fcs.simulation;

import java.util.Map;
import org.lsst.ccs.commons.annotations.LookupField;
import org.lsst.ccs.commons.annotations.LookupField.Strategy;
import org.lsst.ccs.subsystems.fcs.CarouselClamp;
import org.lsst.ccs.subsystems.fcs.Carousel;
import org.lsst.ccs.subsystems.fcs.EPOSEnumerations.EposMode;
import static org.lsst.ccs.subsystems.fcs.FCSCst.FCSLOG;
import org.lsst.ccs.subsystems.fcs.errors.FailedCommandException;
import org.lsst.ccs.subsystems.fcs.errors.RejectedCommandException;
import org.lsst.ccs.subsystems.fcs.errors.SDORequestException;

/**
 * To simulate a controller which can open carousel clamps.
 * @author virieux
 */
public class SimuCarouselClampController extends SimuEPOSController {

    @LookupField(strategy=Strategy.BYNAME)
    private Carousel carousel;
    
    @LookupField(strategy=Strategy.BYNAME)
    private SimuTTC580 hyttc580;
    
    /**
     * Build a new SimuCarouselClampController
     * @param nodeID
     * @param serialNB
     * @param paramsForCurrent
     * @param paramsForProfilePosition
     * @param paramsForHoming 
     */
    public SimuCarouselClampController( 
            int nodeID, String serialNB, 
            Map<String, Integer> paramsForCurrent, 
            Map<String, Integer> paramsForProfilePosition, 
            Map<String, Integer> paramsForHoming) {
        super(nodeID, serialNB, 
                paramsForCurrent, paramsForProfilePosition, paramsForHoming);
    }
    
    @Override
    public void init() {
        this.mode = EposMode.CURRENT;
    }

    /**
     * Write current to the simulated controller.
     * @param currentValue
     * @throws SDORequestException 
     */
    @Override
    public void writeCurrent(int currentValue) {

        FCSLOG.debug(getName() + "==========> ACTUATOR ON");
        
        if (this.carousel.getSocketAtStandby() == null) {
            throw new RejectedCommandException(getName() + " can't writeCurrent to clamp controller "
                    + "when there is no socket at standby position");
        }

        //the clamp is now UNLOCKED : we have to simulate that.
        CarouselClamp clamp;
        if (name.contains("Xminus")) {
            clamp = this.carousel.getSocketAtStandby().getClampXminus();
        } else if (name.contains("Xplus")) {
            clamp = this.carousel.getSocketAtStandby().getClampXplus();
        } else {
            throw new RejectedCommandException(name + ":couldn't find the clamp to unlock");
        }
        hyttc580.simulateClampIsUnlocked(clamp);
        clamp.updateState();
        //we have to publish on status bus the sentValue (for the GUI)
        //not done in CanOPenEPOS
        this.publishData();
    }

    @Override
    public void stopAction()  {
        FCSLOG.debug(name + "==========> ACTUATOR OFF");
        //the clamp is now LOCKED : we have to simulate that.
        CarouselClamp clamp;
        if (name.contains("Xminus")) {
            clamp = this.carousel.getClampXminus();
        } else if (name.contains("Xplus")) {
            clamp = this.carousel.getClampXplus();
        } else {
            throw new FailedCommandException(name + ": unable to find the clamp to unlock.");
        }
        ((SimuCarouselClampLockSensor) clamp.getLockSensor()).simulateClampIsLOCKED();
        clamp.updateState();
        this.publishData();
    }    
    
    
}

==> org-lsst-ccs-subsystem-fcs-main-5.1.2-sources.jar: org/lsst/ccs/subsystems/fcs/simulation/SimuCarouselClampController.java <==

package org.lsst.ccs.subsystems.fcs.simulation;

import org.lsst.ccs.subsystems.fcs.singlefiltertest.SimuCarouselClampLockSensor;
import java.util.Map;
import org.lsst.ccs.commons.annotations.LookupField;
import org.lsst.ccs.commons.annotations.LookupField.Strategy;
import org.lsst.ccs.subsystems.fcs.CarouselClamp;
import org.lsst.ccs.subsystems.fcs.Carousel;
import org.lsst.ccs.subsystems.fcs.EPOSEnumerations.EposMode;
import static org.lsst.ccs.subsystems.fcs.FCSCst.FCSLOG;
import org.lsst.ccs.subsystems.fcs.errors.FailedCommandException;
import org.lsst.ccs.subsystems.fcs.errors.RejectedCommandException;
import org.lsst.ccs.subsystems.fcs.errors.SDORequestException;

/**
 * To simulate a controller which can open carousel clamps.
 * @author virieux
 */
public class SimuCarouselClampController extends SimuEPOSController {

    @LookupField(strategy=Strategy.BYNAME)
    protected Carousel carousel;
    
    @LookupField(strategy=Strategy.BYNAME)
    private SimuTTC580 hyttc580;
    
    /**
     * Build a new SimuCarouselClampController
     * @param nodeID
     * @param serialNB
     * @param paramsForCurrent
     * @param paramsForProfilePosition
     * @param paramsForHoming 
     */
    public SimuCarouselClampController( 
            int nodeID, String serialNB, 
            Map<String, Integer> paramsForCurrent, 
            Map<String, Integer> paramsForProfilePosition, 
            Map<String, Integer> paramsForHoming) {
        super(nodeID, serialNB, 
                paramsForCurrent, paramsForProfilePosition, paramsForHoming);
    }
    
    @Override
    public void init() {
        this.mode = EposMode.CURRENT;
    }

    /**
     * Write current to the simulated controller.
     * @param currentValue
     * @throws SDORequestException 
     */
    @Override
    public void writeCurrent(int currentValue) {

        FCSLOG.debug(getName() + "==========> ACTUATOR ON");
        
        if (this.carousel.getSocketAtStandby() == null) {
            throw new RejectedCommandException(getName() + " can't writeCurrent to clamp controller "
                    + "when there is no socket at standby position");
        }

        //the clamp is now UNLOCKED : we have to simulate that.
        CarouselClamp clamp;
        if (name.contains("Xminus")) {
            clamp = this.carousel.getSocketAtStandby().getClampXminus();
        } else if (name.contains("Xplus")) {
            clamp = this.carousel.getSocketAtStandby().getClampXplus();
        } else {
            throw new RejectedCommandException(name + ":couldn't find the clamp to unlock");
        }
        hyttc580.simulateClampIsUnlocked(clamp);
        clamp.updateState();
        //we have to publish on status bus the sentValue (for the GUI)
        //not done in CanOPenEPOS
        this.publishData();
    }

    @Override
    public void stopAction()  {
        FCSLOG.debug(name + "==========> ACTUATOR OFF");
        //the clamp is now LOCKED : we have to simulate that.
        CarouselClamp clamp;
        if (name.contains("Xminus")) {
            clamp = this.carousel.getClampXminus();
        } else if (name.contains("Xplus")) {
            clamp = this.carousel.getClampXplus();
        } else {
            throw new FailedCommandException(name + ": unable to find the clamp to unlock.");
        }
        ((SimuCarouselClampLockSensor) clamp.getLockSensor()).simulateClampIsLOCKED();
        clamp.updateState();
        this.publishData();
    }    
    
    
}
